==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/bg.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Календар",
    "Todos" : "Задачи",
    "Personal" : "Личен",
    "{actor} created calendar {calendar}" : "{actor} направи календар {calendar}",
    "You created calendar {calendar}" : "Създадохте календара {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} изтри календар {calendar}",
    "You deleted calendar {calendar}" : "Изтрихте календар {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} обнови календар {calendar}",
    "You updated calendar {calendar}" : "Обновихте календар {calendar}",
    "You shared calendar {calendar} as public link" : "Споделихте календара {calendar} с публична връзка",
    "You removed public link for calendar {calendar}" : "Премахнахте публична връзка към календара {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} сподели календара {calendar} с вас",
    "You shared calendar {calendar} with {user}" : "Споделихте календара {calendar} с {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} сподели календар {calendar} с {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} отказа споделянето на календара {calendar} с вас",
    "You unshared calendar {calendar} from {user}" : "Отказахте споделянето на календара {calendar} от {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} отказа споделяне на календар {calendar} от {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} отказа споделяне на календар {calendar} от себеси",
    "You shared calendar {calendar} with group {group}" : "Споделихте календара {calendar} с група {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} сподели календар {calendar} с група {group}",
    "You unshared calendar {calendar} from group {group}" : "Отказахте споделянето на календара {calendar} от група {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} отказа споделяне с календар {calendar} от група {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} създаде събитие {event} в календар {calendar}",
    "You created event {event} in calendar {calendar}" : "Създадохте събитие {event} в календар {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} изтри събитие {event} от календар {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Изтрихте събитие {event} от календар {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} обнови събитие {event} в календар {calendar}",
    "You updated event {event} in calendar {calendar}" : "Обновихте събитие {event} в календар {calendar}",
    "Busy" : "Зает",
    "{actor} created todo {todo} in list {calendar}" : "{actor} създаде задача {todo} в списък {calendar}",
    "You created todo {todo} in list {calendar}" : "Създадохте задача {todo} в списък {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} изтри задача {todo} от списък {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Изтрихте задача {todo} от лист {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} актуализира задача {todo} в списък {calendar}",
    "You updated todo {todo} in list {calendar}" : "Променихте задача {todo} в списък {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} реши задача {todo} в списък {calendar}",
    "You solved todo {todo} in list {calendar}" : "Решихте задача {todo} в списък {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} възобнови задача {todo} в списък {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Възобновихте задача {todo} в списък {calendar}",
    "A <strong>calendar</strong> was modified" : "Промяна на <strong>календар</strong>",
    "A calendar <strong>event</strong> was modified" : "Промяна на календарно <strong>събитие</strong>",
    "A calendar <strong>todo</strong> was modified" : "Промяна на календарна <strong>задача</strong>",
    "Contact birthdays" : "Рождени дни на контакти",
    "Accept" : "Приемане",
    "Contacts" : "Контакти",
    "Technical details" : "Технически детайли",
    "Remote Address: %s" : "Отдалечен адрес: %s",
    "Request ID: %s" : "ID на заявката: %s",
    "Send invitations to attendees" : "Изпращане на покани до участниците",
    "Please make sure to properly set up the email settings above." : "Моля, уверете се, че настройките за изпращане на имейли са коректни.",
    "Automatically generate a birthday calendar" : "Автоматично генериране на календар с рождени дни.",
    "Birthday calendars will be generated by a background job." : "Календарите с рождени дни се генерират от background job.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Това е причината поради която те не се появяват веднага, след като включите опцията.",
    "CalDAV server" : "CalDAV сървър"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/bg.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Календар",
    "Todos" : "Задачи",
    "Personal" : "Личен",
    "{actor} created calendar {calendar}" : "{actor} направи календар {calendar}",
    "You created calendar {calendar}" : "Създадохте календара {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} изтри календар {calendar}",
    "You deleted calendar {calendar}" : "Изтрихте календар {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} обнови календар {calendar}",
    "You updated calendar {calendar}" : "Обновихте календар {calendar}",
    "You shared calendar {calendar} as public link" : "Споделихте календара {calendar} с публична връзка",
    "You removed public link for calendar {calendar}" : "Премахнахте публична връзка към календара {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} сподели календара {calendar} с вас",
    "You shared calendar {calendar} with {user}" : "Споделихте календара {calendar} с {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} сподели календар {calendar} с {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} отказа споделянето на календара {calendar} с вас",
    "You unshared calendar {calendar} from {user}" : "Отказахте споделянето на календара {calendar} от {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} отказа споделяне на календар {calendar} от {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} отказа споделяне на календар {calendar} от себеси",
    "You shared calendar {calendar} with group {group}" : "Споделихте календара {calendar} с група {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} сподели календар {calendar} с група {group}",
    "You unshared calendar {calendar} from group {group}" : "Отказахте споделянето на календара {calendar} от група {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} отказа споделяне с календар {calendar} от група {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} създаде събитие {event} в календар {calendar}",
    "You created event {event} in calendar {calendar}" : "Създадохте събитие {event} в календар {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} изтри събитие {event} от календар {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Изтрихте събитие {event} от календар {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} обнови събитие {event} в календар {calendar}",
    "You updated event {event} in calendar {calendar}" : "Обновихте събитие {event} в календар {calendar}",
    "Busy" : "Зает",
    "{actor} created todo {todo} in list {calendar}" : "{actor} създаде задача {todo} в списък {calendar}",
    "You created todo {todo} in list {calendar}" : "Създадохте задача {todo} в списък {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} изтри задача {todo} от списък {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Изтрихте задача {todo} от списък {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} актуализира задача {todo} в списък {calendar}",
    "You updated todo {todo} in list {calendar}" : "Променихте задача {todo} в списък {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} реши задача {todo} в списък {calendar}",
    "You solved todo {todo} in list {calendar}" : "Решихте задача {todo} в списък {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} възобнови задача {todo} в списък {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Възобновихте задача {todo} в списък {calendar}",
    "A <strong>calendar</strong> was modified" : "Промяна на <strong>календар</strong>",
    "A calendar <strong>event</strong> was modified" : "Промяна на календарно <strong>събитие</strong>",
    "A calendar <strong>todo</strong> was modified" : "Промяна на календарна <strong>задача</strong>",
    "Contact birthdays" : "Рождени дни на контакти",
    "Accept" : "Приемане",
    "Contacts" : "Контакти",
    "Technical details" : "Технически детайли",
    "Remote Address: %s" : "Отдалечен адрес: %s",
    "Request ID: %s" : "ID на заявката: %s",
    "Send invitations to attendees" : "Изпращане на покани до участниците",
    "Automatically generate a birthday calendar" : "Автоматично генериране на календар с рождени дни.",
    "Birthday calendars will be generated by a background job." : "Календарите с рождени дни се генерират от background job.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Това е причината поради която те не се появяват веднага, след като включите опцията.",
    "CalDAV server" : "CalDAV сървър",
    "Please make sure to properly set up the email settings above." : "Моля, уверете се, че настройките за изпращане на имейли са коректни."
},
"nplurals=2; plural=(n != 1);");
